HelpdeskArticle class

Constructors

HelpdeskArticle.fromMap(Map map)

Properties

category ↔ String
getter/setter pair
content ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ num
getter/setter pair
parentId ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section ↔ String
getter/setter pair
title ↔ String
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

formatDate(String date) → DateTime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited